https://github.com/python/cpython/commit/8a4d4f37abb9fa639fdc5d7003c4067904cdcc6b
commit: 8a4d4f37abb9fa639fdc5d7003c4067904cdcc6b
branch: main
author: Eric Snow <ericsnowcurren...@gmail.com>
committer: ericsnowcurrently <ericsnowcurren...@gmail.com>
date: 2025-04-25T21:10:43Z
summary:

gh-132781: Make NotShareableError a TypeError Subclass (gh-132973)

It was a subclass of ValueError. However, shareability is a feature of types, 
not values.

files:
M Python/crossinterp_exceptions.h

diff --git a/Python/crossinterp_exceptions.h b/Python/crossinterp_exceptions.h
index 39993648f275f4..857c4d1e379a0e 100644
--- a/Python/crossinterp_exceptions.h
+++ b/Python/crossinterp_exceptions.h
@@ -46,14 +46,13 @@ static PyTypeObject _PyExc_InterpreterNotFoundError = {
 };
 PyObject *PyExc_InterpreterNotFoundError = (PyObject 
*)&_PyExc_InterpreterNotFoundError;
 
 /* NotShareableError extends ValueError */
 
 static int
 _init_notshareableerror(exceptions_t *state)
 {
     const char *name = "interpreters.NotShareableError";
-    // XXX Inherit from TypeError.
-    PyObject *base = PyExc_ValueError;
+    PyObject *base = PyExc_TypeError;
     PyObject *ns = NULL;
     PyObject *exctype = PyErr_NewException(name, base, ns);
     if (exctype == NULL) {
@@ -94,7 +93,7 @@ _ensure_notshareableerror(PyThreadState *tstate,
         }
     }
     else {
-        exctype = PyExc_ValueError;
+        exctype = PyExc_TypeError;
     }
     _PyErr_SetObject(tstate, exctype, msgobj);
     // We have to set the context manually since _PyErr_SetObject() doesn't.
@@ -46,14 +46,13 @@ static PyTypeObject _PyExc_InterpreterNotFoundError = {
*)&_PyExc_InterpreterNotFoundError;
 
-/* NotShareableError extends ValueError */
+/* NotShareableError extends TypeError */
 
 static int

_______________________________________________
Python-checkins mailing list -- python-checkins@python.org
To unsubscribe send an email to python-checkins-le...@python.org
https://mail.python.org/mailman3/lists/python-checkins.python.org/
Member address: arch...@mail-archive.com

Reply via email to